"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Color = require("color");
function scale(_a) {
    var base = _a.base, steps = _a.steps, _b = _a.lighten, lighten = _b === void 0 ? 1 : _b, _c = _a.hueShift, hueShift = _c === void 0 ? 0 : _c, _d = _a.saturate, saturate = _d === void 0 ? 0 : _d;
    if (steps !== parseInt(steps.toString(), 10) || steps < 0) {
        throw new Error('The "steps" argmuent must be an positive integer.');
    }
    if (typeof lighten !== 'number' || lighten > 1 || lighten < -1) {
        throw new Error('The "lighten" argument must be a number between 1 and -1.');
    }
    if (typeof hueShift !== 'number') {
        throw new Error('The "hueShift" argument must be a number.');
    }
    if (typeof saturate !== 'number' || saturate > 1 || saturate < -1) {
        throw new Error('The "saturate" argument must be a number between 1 and -1.');
    }
    var color = Color(base);
    var colors = [];
    for (var step = 1; step <= steps; step++) {
        var mixinColor = Color(lighten > 0 ? 'white' : 'black');
        colors.push(color
            .rotate((hueShift * step) / steps)
            .saturate((saturate * step) / steps)
            .mix(mixinColor, (Math.abs(lighten) * step) / steps)
            .hex());
    }
    return colors;
}
exports.scale = scale;
exports.default = scale;
